# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.2.1

([Full Changelog](https://github.com/trungleduc/jupyterpack/compare/v0.2.0...5fb3882b63c2497b1d485e04031e259cdabae36c))

### Enhancements made

- update fetch rule [#6](https://github.com/trungleduc/jupyterpack/pull/6) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/jupyterpack/graphs/contributors?from=2025-10-01&to=2025-10-01&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fjupyterpack+involves%3Atrungleduc+updated%3A2025-10-01..2025-10-01&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.2.0

([Full Changelog](https://github.com/trungleduc/jupyterpack/compare/12083f5da5f8428ac882173ba1053ac83e9c2055...595d35d7591d91efbede78033911bfb633ee48b0))

### Enhancements made

- ping frame [#5](https://github.com/trungleduc/jupyterpack/pull/5) ([@trungleduc](https://github.com/trungleduc))
- Fix base url [#2](https://github.com/trungleduc/jupyterpack/pull/2) ([@trungleduc](https://github.com/trungleduc))
- Reboot [#1](https://github.com/trungleduc/jupyterpack/pull/1) ([@trungleduc](https://github.com/trungleduc))

### Other merged PRs

- keep sw alive [#4](https://github.com/trungleduc/jupyterpack/pull/4) ([@trungleduc](https://github.com/trungleduc))
- update readme [#3](https://github.com/trungleduc/jupyterpack/pull/3) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/jupyterpack/graphs/contributors?from=2025-02-09&to=2025-10-01&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fjupyterpack+involves%3Atrungleduc+updated%3A2025-02-09..2025-10-01&type=Issues)
